<?php

namespace Drupal\tellstick\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;

/**
 * Defines the Tellstick Data item entity.
 *
 * @ingroup tellstick
 *
 * @ContentEntityType(
 *   id = "tellstick_data",
 *   label = @Translation("Tellstick Data item"),
 *   label_singular = @Translation("Tellstick Data item"),
 *   label_plural = @Translation("Tellstick Data items"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Tellstick data item",
 *     plural = "@count Tellstick data items"
 *   ),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\tellstick\TellstickDataListBuilder",
 *     "views_data" = "Drupal\tellstick\Entity\TellstickDataViewsData",
 *     "translation" = "Drupal\Core\Entity\EntityTranslationHandler",
 *
 *     "form" = {
 *       "delete" = "Drupal\tellstick\Form\TellstickDataItemDeleteForm",
 *     },
 *     "access" = "Drupal\tellstick\Access\TellstickDataAccessControlHandler",
 *
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *   },
 *   base_table = "tellstick_data",
 *   data_table = "tellstick_data_field_data",
 *   translatable = TRUE,
 *   admin_permission = "administer tellstick",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "sensor" = "sensor",
 *     "uid" = "user_id",
 *     "langcode" = "langcode",
 *     "status" = "status",
 *   },
 *   links = {
 *     "canonical" = "/tellstick/data/{tellstick_data}",
 *     "collection" = "/tellstick/data",
 *     "delete-form" = "/tellstick/data/{tellstick_data}/delete",
 *   },
 * )
 */
class TellstickData extends ContentEntityBase implements TellstickDataInterface {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage_controller, array &$values) {
    parent::preCreate($storage_controller, $values);
    $values += [
      'user_id' => \Drupal::currentUser()->id(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setCreatedTime($timestamp) {
    $this->set('created', $timestamp);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwner() {
    return $this->get('user_id')->entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getOwnerId() {
    return $this->get('user_id')->target_id;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwnerId($uid) {
    $this->set('user_id', $uid);
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function setOwner(UserInterface $account) {
    $this->set('user_id', $account->id());
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['status'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('Publishing status'))
      ->setDescription(t('A boolean indicating whether the Flag list item is published.'))
      ->setDefaultValue(TRUE);

    $fields['sensor'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Sensor Id'))
      ->setDescription(t('The sensor Id.'));

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['data'] = BaseFieldDefinition::create('map')
      ->setLabel(t('Serialized data'))
      ->setDescription(t('The Serialized data.'));

    return $fields;
  }

}
