<?php

namespace Drupal\tellstick\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Entity\EntityDeleteFormTrait;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for deleting Tellstick Sensor entities.
 *
 * @ingroup tellstick
 */
class TellstickDataItemDeleteForm extends ContentEntityConfirmFormBase {
  use EntityDeleteFormTrait {
    getQuestion as traitGetQuestion;
    logDeletionMessage as traitLogDeletionMessage;
    getDeletionMessage as traitGetDeletionMessage;
    getCancelUrl as traitGetCancelUrl;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildForm($form, $form_state);
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity = $this->getEntity();
    $message = $this->getDeletionMessage();

    // Make sure that deleting a translation does not delete the whole entity.
    if (!$entity->isDefaultTranslation()) {
      $untranslated_entity = $entity->getUntranslated();
      $untranslated_entity->removeTranslation($entity->language()->getId());
      $untranslated_entity->save();
      $form_state->setRedirectUrl($untranslated_entity->toUrl('canonical'));
    }
    else {
      $entity->delete();
      $form_state->setRedirectUrl($this->getRedirectUrl());
    }

    $this->messenger()->addStatus($message);
    $this->logDeletionMessage();
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {

    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity = $this
      ->getEntity();
    $dateFormatter = \Drupal::service('date.formatter');
    $tellstickService = \Drupal::service('tellstick');
    $sensorId = $entity->get('sensor')->getString();

    return $this
      ->t('Are you sure you want to delete the @entity-type for @sensor from @created?', [
        '@entity-type' => $entity
          ->getEntityType()
          ->getSingularLabel(),
        '@sensor' => $tellstickService
          ->getTellstickSensorById($sensorId)->getSensor(),
        '@created' => $dateFormatter->format(
        $entity->getCreatedTime(),
        'short'
        ),
      ]);
  }

}
