<?php

namespace Drupal\tellstick\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A form to set basic properties for the Sensors.
 */
class TellstickSensorSettingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tellstick.sensor_settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tellstick_sensor_setting_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tellstick.sensor_settings');

    $form['live_windsensors'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! Wind sensors'),
    ];
    $form['live_windsensors']['offset'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Wind direction offset'),
      '#size' => 4,
      '#maxlength' => 10,
      '#default_value' => $config->get('offset'),
      '#description' => $this->t("Add an offset, in degrees, to the Wind Direction. This is useful if you can't mount it facing north."),
    ];

    $form['live_thermometers'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! Thermometers'),
    ];
    $form['live_thermometers']['temperature_unit'] = [
      '#type' => 'radios',
      '#title' => $this->t('Temperature unit'),
      '#options' => [0 => 'Celsius', 1 => 'Fahrenheit', 2 => 'Kelvin'],
      '#default_value' => $config->get('temperature_unit'),
      '#description' => $this->t('Select unit for all thermometers. (Kelvin assumes you have selected Celsius on your units.)'),
    ];

    $form['live_lost_sensor_timeout'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! Sensor timeout'),
    ];
    $form['live_lost_sensor_timeout']['sensor_timeout'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Sensor timeout'),
      '#size' => 4,
      '#maxlength' => 10,
      '#default_value' => $config->get('sensor_timeout'),
      '#description' => $this->t('After how long time, in seconds, will a sensor be grayed out when there has been no signal received from it.'),
    ];

    $form['live_battery_status'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Telldus Live! Battery status'),
    ];
    $form['live_battery_status']['battery_status'] = [
      '#type' => 'radios',
      '#title' => $this->t('Battery status'),
      '#options' => [0 => 'Do not show status', 1 => 'Show the status, if supported'],
      '#default_value' => $config->get('battery_status'),
      '#description' => $this->t('Decide if you want to show the battery status together with the sensor values in views. The sensor name is always shown in red if the battery level is too low.'),
    ];
    $form['live_battery_status']['battery_level'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Battery alarm level'),
      '#size' => 4,
      '#maxlength' => 10,
      '#default_value' => $config->get('battery_level'),
      '#description' => $this->t('The battery level, in %, for which the low battery indicator shall be triggered.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    // Validate that Battery is between 0% and 100%.
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('tellstick.sensor_settings')
      ->set('offset',
        $form_state->getValue('offset'))
      ->save();
    $this->config('tellstick.sensor_settings')
      ->set('temperature_unit',
        $form_state->getValue('temperature_unit'))
      ->save();
    $this->config('tellstick.sensor_settings')
      ->set('sensor_timeout',
        $form_state->getValue('sensor_timeout'))
      ->save();
    $this->config('tellstick.sensor_settings')
      ->set('battery_status',
        $form_state->getValue('battery_status'))
      ->save();
    $this->config('tellstick.sensor_settings')
      ->set('battery_level',
        $form_state->getValue('battery_level'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
