<?php

namespace Drupal\tellstick\Form;

use Drupal\tellstick\Entity\TellstickSensor;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Form controller for Tellstick edit forms.
 *
 * From the following page: https://
 *   www.drupal.org/docs/8/api/form-api/confirmformbase-to-confirm-an-action.
 *
 * @ingroup tellstick
 */
class TellstickSensorToggleForm extends ConfirmFormBase {

  /**
   * The Tellstick service.
   *
   * @var \Drupal\tellstick\TelltickService
   */
  protected $tellstickService;

  /**
   * The id of the sensor.
   *
   * @var int
   */
  protected $tellstickSensor;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form,
    FormStateInterface $form_state,
    TellstickSensor $tellstick_sensor = NULL) {
    $this->tellstickSensor = $tellstick_sensor;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tellstick_sensor_toggle_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this
      ->t('Are you sure you want to @toggle the @name sensor?', [
        '@toggle' => $this->tellstickSensor->getIgnored() ?
          $this->t('unhide') : $this->t('hide'),
          '@name' => $this->tellstickSensor->get('sensor')->value,
      ],
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('tellstick.sensor_block_setting_form');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this
      ->t('Please note that hidden sensors are not visible in the block.');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $sensorName = $this->tellstickSensor->get('sensor')->value;
    $sensorIgnored = $this->tellstickSensor->getIgnored();

    $this->tellstickSensor->setIgnored(!$sensorIgnored)->save();

    // Set message that sensor is toggled.
    $message = $this->t('Sensor @name is now @sensorIgnored.', [
      '@name' => $sensorName,
      '@sensorIgnored' => $sensorIgnored ?
        $this->t('visible') :
        $this->t('hidden'),
      ],
    );
    $this->messenger()->addStatus($message);
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
