<?php

namespace Drupal\tellstick\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A field that displays the sensor id in different ways.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("tsensor")
 */
class TellstickHandlerFieldSensor extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function defineOptions() {
    $options = parent::defineOptions();
    if (isset($this->definition['sensorType'])) {
      $options['sensorType'] = [
        'default' => $this->definition['sensorType'],
      ];
    }
    else {
      $options['sensorType'] = [
        'default' => 'name',
      ];
    }
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['sensorType'] = [
      '#type' => 'select',
      '#title' => $this->t('Sensor presentation'),
      '#options' => [
        'id' => $this->t('By id'),
        'name' => $this->t('By name'),
      ],
      '#default_value' => $this->options['sensorType'],
      '#description' => $this->t('Select how to present the Sensor Id.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function render($items) {
    $item = $this->getValue($items);
    if ($this->options['sensorType'] == 'name') {
      $item = $this->getSensorValue($item);
    }
    return $this->sanitizeValue($item);
  }

  /**
   * {@inheritdoc}
   */
  private function getSensorValue($value) {
    // Use the service instead...
    $query = \Drupal::database()->select('tellstick_data_field_data', 'td')
      ->condition('td.sensor', $value, '=')
      ->fields('td', ['data'])
      ->range(0, 1)
      ->orderBy('td.id', 'DESC');
    $result = $query->execute();
    foreach ($result as $record) {
      $temp_value = unserialize($record->data);
    }
    return $temp_value['name'];
  }

}
