<?php

namespace Drupal\tellstick;

use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Component\Utility\SortArray;

/**
 * Provides a listing of Flagging collection type entities.
 */
class TellstickSensorListBuilder extends EntityListBuilder {

  // TODO: Add Weight sort / update to the table.
  // https://www.drupal.org/project/drupal/issues/2989889

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Name');
    $header['place'] = $this->t('Place');
    $header['id'] = $this->t('Id');
    $header['created'] = $this->t('Sensor Created');
    $header['chnaged'] = $this->t('Sensor Updated');
    $header['visible'] = $this->t('Local Visibility');
    $header['battery'] = $this->t('Battery level %');
    $header['weight'] = $this->t('Weight');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row = [];
    $row['label'] = $entity->getSensor();
    $row['place'] = $entity->getPlace();
    $row['id'] = $entity->id();
    $row['created'] = $entity->getCreated();
    $row['changed'] = $entity->getChanged();
    $row['visible'] = $entity->getIgnored() ?
      $this->t("Hidden") :
      $this->t("Visible");
    $row['battery'] = $entity->getBattery();
    $row['weight'] = $entity->getWeight();
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEntityIds() {
    // A messy way of sorting as the entity doesn't have access
    // to all fields.
    $sensor_array = [];
    $sensors = $this->getStorage()->loadMultiple();
    foreach ($sensors as $sensor) {
      $sensor_array[$sensor->id()]['title'] = $sensor->getSensor();
    }
    if (!empty($sensor_array)) {
      uasort($sensor_array, [SortArray::class, 'sortByTitleElement']);
      foreach ($sensor_array as $key => $sensor) {
        $sensor_array[$key] = $key;
      }
    }
    return $sensor_array;
  }

}
